@@ -46,7 +46,7 @@ test_that("interactions subsetted by adding additional information", {
   rattusaves <- get_interactions_by_taxa(sourcetaxon = "Rattus rattus", targettaxon="Aves", interactiontype= interaction_types)
   expect_equal(class(rattus$source_taxon_name), "character")
   expect_true(dim(rattus)[1] > 0)
-  expect_less_than(dim(rattusaves)[1], dim(rattus)[1])
+  expect_lt(dim(rattusaves)[1], dim(rattus)[1])
   expect_equal(dim(merge(rattusaves,rattus, all.x=T, all.y=T)), dim(rattus))
 })
 
@@ -54,7 +54,7 @@ test_that("interactions subsetted by adding additional information all interacti
   rattus <- get_interactions_by_taxa(sourcetaxon = "Rattus rattus")
   rattusaves <- get_interactions_by_taxa(sourcetaxon = "Rattus rattus", targettaxon="Aves")
   expect_true(dim(rattus)[1] > 0)
-  expect_less_than(dim(rattusaves)[1], dim(rattus)[1])
+  expect_lt(dim(rattusaves)[1], dim(rattus)[1])
   # note that some interaction types (e.g. interactsWith) are symmetric
   # if a specific source (e.g. Thessen et al. 2014) reported a -[:INTERACTS_WITH]-> b and (a separate entry) b -[:INTERACTS_WITH]-> a, then both show up when looking for interactions between a and b, because the inverse of interactsWith is interactsWith.
   expect_equal(dim(merge(rattusaves,rattus, all.x=T, all.y=T)), dim(rattus))
@@ -64,7 +64,7 @@ test_that("interactions subsetted by adding additional information all interacti
   rattus <- get_interactions_by_taxa(sourcetaxon = "Rattus rattus", returnobservations = T)
   rattusaves <- get_interactions_by_taxa(sourcetaxon = "Rattus rattus", targettaxon="Aves", returnobservations = T)
   expect_true(dim(rattus)[1] > 0)
-  expect_less_than(dim(rattusaves)[1], dim(rattus)[1])
+  expect_lt(dim(rattusaves)[1], dim(rattus)[1])
   # note that some interaction types (e.g. interactsWith) are symmetric
   # if a specific source (e.g. Thessen et al. 2014) reported a -[:INTERACTS_WITH]-> b and (a separate entry) b -[:INTERACTS_WITH]-> a, then both show up when looking for interactions between a and b, because the inverse of interactsWith is interactsWith.
   expect_equal(dim(merge(unique(rattusaves),unique(rattus), all.x=T, all.y=T)), dim(unique(rattus)))
@@ -74,7 +74,7 @@ test_that("interactions subsetted by adding additional information using otherke
   rattus <- get_interactions_by_taxa(sourcetaxon = "Rattus rattus")
   rattusaves <- get_interactions_by_taxa(sourcetaxon = "Rattus rattus", otherkeys = list("targetTaxon" = "Aves"))
   expect_true(dim(rattus)[1] > 0)
-  expect_less_than(dim(rattusaves)[1], dim(rattus)[1])
+  expect_lt(dim(rattusaves)[1], dim(rattus)[1])
   # note that some interaction types (e.g. interactsWith) are symmetric
   # if a specific source (e.g. Thessen et al. 2014) reported a -[:INTERACTS_WITH]-> b and (a separate entry) b -[:INTERACTS_WITH]-> a, then both show up when looking for interactions between a and b, because the inverse of interactsWith is interactsWith.
   expect_equal(dim(merge(unique(rattusaves),unique(rattus), all.x=T, all.y=T)), dim(unique(rattus)))
@@ -115,3 +115,8 @@ test_that("interaction matrix with interaction type can be retrieved", {
   interaction.matrix <- get_interaction_matrix(list('Cymothoa excisa'), list('Micropogonias undulatus'), 'parasiteOf')
   expect_equal(unlist(interaction.matrix[[2]]), 1)
 })
+
+test_that("interactions can be retrieved by type", {
+  interactions <- rglobi::get_interactions_by_type(interactiontype = c('eats', 'eatenBy'), showfield = c('source_taxon_name', 'interaction_type', 'target_taxon_name'), otherkeys = list(limit=5))
+  expect_equal(length(interactions$source_taxon_name), 5)
+})
